==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/node_admin.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="node_admin.php" method="post">
<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "node_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">

			<?php
			if (isset($display) && $display == "list_users") {
			?>
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="5">
						<?php echo $lang['section_users'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td>
						<b><?php echo $lang['txt_nic'];?></b><br />
					</td>
					<td>
						<b><?php echo $lang['txt_name'];?></b><br />
					</td>
					<td>
						<b><?php echo $lang['txt_hometown'];?></b><br />
					</td>
					<td>
						<b><?php echo $lang['txt_join_date'];?></b><br />
					</td>
				</tr>
				<?php
				if (isset($users[0])) {
				foreach($users as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['user_id'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['user_nic'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['user_firstname'] . " " . $i['user_surname'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['user_hometown'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['user_create_datetime'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td class="txt_footer" colspan="4">
						<?php
						if (isset($lang['arr_lang_name'][$i['language_id']])) {
						    echo $lang['arr_lang_name'][$i['language_id']];
						}
						?>,
						<?php
						if (isset($lang['arr_user_priv'][$i['level_id']])) {
						    echo $lang['arr_user_priv'][$i['level_id']];
						}
						?><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_users'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>

			<?php
			}
			elseif (isset($display) && $display == "list_groups") {
			?>
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="6">
						<?php echo $lang['menu_group_list'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_group'];?></b><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_type'];?></b><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_members'];?></b><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_status'];?></b><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_create_date'];?></b><br />
					</td>
				</tr>
				<?php
				if (isset($groups[0])) {
				foreach($groups as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="g_admin.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_id'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['group_title'];?><br />
					</td>
					<td valign="top">
						<?php echo $lang['arr_group_type'][$i['group_type']];?><br />
					</td>
					<td valign="top">
						<?php echo $i['group_total_members'];?><br />
					</td>
					<td valign="top">
						<?php echo $lang['arr_group_status'][$i['group_status']];?><br />
					</td>
					<td nowrap valign="top">
						<?php echo $i['group_create_datetime'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top">
						&nbsp;<br />
					</td>
					<td class="txt_footer" valign="top" colspan="5">
						<?php
						if (isset($lang['arr_group_genre'][$i['genre_id']])) {
						    echo $lang['arr_group_genre'][$i['genre_id']];
						}
						?>,
						<?php
						if ($today > $i['group_election_date']) {
						    echo "<span class='txt_red'>" . $i['group_election_date'] . "</span>";
						}
						else {
							echo $i['group_election_date'];
						}
						?><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_groups'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>

			<?php
			}
			?>
		</td>
	</tr>
</table>
</form>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/node_admin.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "node_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['section_admin'];?><br />
						<hr />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
